@@ -6,10 +6,12 @@
 */
 
 #include "ldapconnection.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "kldap_config.h" // LDAP_FOUND
 #include "ldapdefs.h"
 
-#include "ldap_debug.h"
+#include "ldap_core_debug.h"
 #include <KLocalizedString>
 #include <cstdlib>
 
@@ -30,7 +32,7 @@ static bool ldapoperation_sasl_initialized = false;
 #include <lber.h>
 #include <ldap.h>
 #else
-#include <w32-ldap-help.h>
+#include "w32-ldap-help.h"
 #endif // HAVE_WINLDAP_H
 
 #ifndef LDAP_OPT_SUCCESS
@@ -39,7 +41,7 @@ static bool ldapoperation_sasl_initialized = false;
 
 #endif
 
-using namespace KLDAP;
+using namespace KLDAPCore;
 
 class Q_DECL_HIDDEN LdapConnection::LdapConnectionPrivate
 {
@@ -220,7 +222,7 @@ int LdapConnection::connect()
     int timeout = d->mServer.timeout();
 
     url = d->mServer.security() == LdapServer::SSL ? QStringLiteral("ldaps") : QStringLiteral("ldap");
-    url += QLatin1String("://");
+    url += "://"_L1;
     url += d->mServer.host();
     url += QLatin1Char(':');
     url += QString::number(d->mServer.port());
