@@ -28,7 +28,7 @@
 #include <lber.h>
 #include <ldap.h>
 #else
-#include <w32-ldap-help.h>
+#include "w32-ldap-help.h"
 #endif // HAVE_WINLDAP_H
 #endif // LDAP_FOUND
 
@@ -227,7 +227,7 @@ int LdapOperation::LdapOperationPrivate::bind(const QByteArray &creds, SASL_Call
     int ret;
 
     if (server.auth() == LdapServer::SASL) {
-#if !defined(HAVE_WINLDAP_H)
+#if !HAVE_WINLDAP_H
         auto saslconn = (sasl_conn_t *)mConnection->saslHandle();
         sasl_interact_t *client_interact = nullptr;
         const char *out = nullptr;
