@@ -1,11 +1,13 @@
 /*
- * SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "ldapclientsearchconfig.h"
-#include <kldapcore/ldapserver.h>
+using namespace Qt::Literals::StringLiterals;
+
+#include "kldapcore/ldapserver.h"
 
 #include <KConfig>
 #include <qt6keychain/keychain.h>
@@ -20,7 +22,7 @@ public:
     ~LdapClientSearchConfigPrivate() = default;
 };
 
-Q_GLOBAL_STATIC_WITH_ARGS(KConfig, s_config, (QLatin1String("kabldaprc"), KConfig::NoGlobals))
+Q_GLOBAL_STATIC_WITH_ARGS(KConfig, s_config, ("kabldaprc"_L1, KConfig::NoGlobals))
 
 KConfig *LdapClientSearchConfig::config()
 {
