@@ -1,15 +1,17 @@
 /*
- * SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "ldapclientsearchconfigreadconfigjob.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "ldapclient_debug.h"
 
+#include "kldapcore/ldapdn.h"
 #include <KConfig>
 #include <KLocalizedString>
-#include <kldapcore/ldapdn.h>
 #include <qt6keychain/keychain.h>
 using namespace QKeychain;
 
@@ -108,17 +110,17 @@ void LdapClientSearchConfigReadConfigJob::readConfig()
 
     QString tmp = mConfig.readEntry(prefix + QStringLiteral("Security%1").arg(mServerIndex), QStringLiteral("None"));
     mServer.setSecurity(KLDAPCore::LdapServer::None);
-    if (tmp == QLatin1String("SSL")) {
+    if (tmp == "SSL"_L1) {
         mServer.setSecurity(KLDAPCore::LdapServer::SSL);
-    } else if (tmp == QLatin1String("TLS")) {
+    } else if (tmp == "TLS"_L1) {
         mServer.setSecurity(KLDAPCore::LdapServer::TLS);
     }
 
     tmp = mConfig.readEntry(prefix + QStringLiteral("Auth%1").arg(mServerIndex), QStringLiteral("Anonymous"));
     mServer.setAuth(KLDAPCore::LdapServer::Anonymous);
-    if (tmp == QLatin1String("Simple")) {
+    if (tmp == "Simple"_L1) {
         mServer.setAuth(KLDAPCore::LdapServer::Simple);
-    } else if (tmp == QLatin1String("SASL")) {
+    } else if (tmp == "SASL"_L1) {
         mServer.setAuth(KLDAPCore::LdapServer::SASL);
     }
 
